window.Gleam.initSearch([{"doc":"gleam_mongo","title":"gleam_mongo","content":"# gleam_mongo\n\nA mongodb driver for gleam\n\n## Quick start\n\n```sh\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\n```sh\ngleam add gleam_mongo\n```\n\n## Roadmap\n\n- [x] support basic mongodb commands\n- [x] support aggregation\n- [x] support connection strings\n- [x] support authentication\n- [ ] support mongodb cursors\n- [ ] support connection pooling\n- [ ] support bulk operations\n- [ ] support transactions\n- [ ] support other mongodb commands\n- [ ] support tls\n- [ ] support clusters\n- [ ] support change streams\n\n## Usage\n\n```gleam\nimport mongo\nimport bson/types\nimport comics/draw\nimport mongo/utils\nimport gleam/result\nimport mongo/aggregation.{add_fields, aggregate, exec, lookup}\n\npub fn main() {\n  let assert Ok(comix_db) =\n    mongo.connect(&quot;mongodb://Sketch:RoadKill@localhost/comix_zone&quot;)\n\n  let characters =\n    comix_db\n    |&gt; mongo.collection(&quot;characters&quot;)\n\n  characters\n  |&gt; mongo.insert_one(types.Document([\n    #(&quot;name&quot;, types.Str(&quot;Alissa&quot;)),\n    #(&quot;race&quot;, types.Str(&quot;human&quot;)),\n  ]))\n\n  characters\n  |&gt; mongo.update_one(\n    types.Document([#(&quot;name&quot;, types.Str(&quot;Mortus&quot;))]),\n    types.Document([#(&quot;$set&quot;, types.Document([#(&quot;race&quot;, types.Str(&quot;mutant&quot;))]))]),\n    [utils.Upsert],\n  )\n\n  characters\n  |&gt; aggregate\n  |&gt; lookup(\n    from: &quot;styles&quot;,\n    local_field: &quot;name&quot;,\n    foreign_field: &quot;subject&quot;,\n    alias: &quot;style&quot;,\n  )\n  |&gt; add_fields(types.Document([\n    #(\n      &quot;style&quot;,\n      types.Document([\n        #(&quot;$arrayElemAt&quot;, types.Array([types.Str(&quot;$style&quot;), types.Integer(0)])),\n      ]),\n    ),\n  ]))\n  |&gt; exec\n  |&gt; result.unwrap([])\n  |&gt; draw.characters\n}\n```\n","url":"index.html"},{"doc":"mongo/utils","title":"FindOption","content":"pub type FindOption {\n  Sort(types.Value)\n  Projection(types.Value)\n  Skip(Int)\n  Limit(Int)\n}\n\nSort(types.Value)\n\n\nProjection(types.Value)\n\n\nSkip(Int)\n\n\nLimit(Int)\n\n\nSynonyms:\nmongo/utils.FindOption\nmongo/utils FindOption","url":"mongo/utils.html#FindOption"},{"doc":"mongo/utils","title":"MongoError","content":"pub type MongoError {\n  MongoError(code: Int, msg: String, source: types.Value)\n}\n\nMongoError(code: Int, msg: String, source: types.Value)\n\n\nSynonyms:\nmongo/utils.MongoError\nmongo/utils MongoError","url":"mongo/utils.html#MongoError"},{"doc":"mongo/utils","title":"UpdateOption","content":"pub type UpdateOption {\n  Upsert\n  ArrayFilters(List(types.Value))\n}\n\nUpsert\n\n\nArrayFilters(List(types.Value))\n\n\nSynonyms:\nmongo/utils.UpdateOption\nmongo/utils UpdateOption","url":"mongo/utils.html#UpdateOption"},{"doc":"mongo/utils","title":"default_error","content":"pub const default_error: MongoError = MongoError(\n  code: -16,\n  msg: &quot;&quot;,\n  source: types.Null,\n)\n\nSynonyms:\nmongo/utils.default_error\nmongo/utils default_error","url":"mongo/utils.html#default_error"},{"doc":"mongo/utils","title":"mongo/utils","content":"","url":"mongo/utils.html"},{"doc":"tcp","title":"Socket","content":"pub external type Socket\n\n\nSynonyms:\ntcp.Socket\ntcp Socket","url":"tcp.html#Socket"},{"doc":"tcp","title":"TCPResult","content":"pub type TCPResult {\n  Ok\n}\n\nOk\n\n\nSynonyms:\ntcp.TCPResult\ntcp TCPResult","url":"tcp.html#TCPResult"},{"doc":"tcp","title":"connect","content":"pub fn connect(host: String, port: Int) -&gt; Result(Socket, Nil)\n\nSynonyms:\ntcp.connect\ntcp connect","url":"tcp.html#connect"},{"doc":"tcp","title":"receive","content":"pub fn receive(socket: Socket) -&gt; Result(BitString, Nil)\n\nSynonyms:\ntcp.receive\ntcp receive","url":"tcp.html#receive"},{"doc":"tcp","title":"send","content":"pub fn send(socket: Socket, data: BitString) -&gt; TCPResult\n\nSynonyms:\ntcp.send\ntcp send","url":"tcp.html#send"},{"doc":"tcp","title":"tcp","content":"","url":"tcp.html"},{"doc":"mongo/scram","title":"first_message","content":"pub fn first_message(payload: String) -&gt; Value\n\nSynonyms:\nmongo/scram.first_message\nmongo/scram first_message","url":"mongo/scram.html#first_message"},{"doc":"mongo/scram","title":"first_payload","content":"pub fn first_payload(username: String) -&gt; String\n\nSynonyms:\nmongo/scram.first_payload\nmongo/scram first_payload","url":"mongo/scram.html#first_payload"},{"doc":"mongo/scram","title":"hi","content":"pub fn hi(password: String, salt: BitString, iterations: Int) -&gt; BitString\n\nSynonyms:\nmongo/scram.hi\nmongo/scram hi","url":"mongo/scram.html#hi"},{"doc":"mongo/scram","title":"parse_first_reply","content":"pub fn parse_first_reply(reply: List(#(String, Value))) -&gt; Result(\n  #(#(String, String, Int), String, Int),\n  Nil,\n)\n\nSynonyms:\nmongo/scram.parse_first_reply\nmongo/scram parse_first_reply","url":"mongo/scram.html#parse_first_reply"},{"doc":"mongo/scram","title":"parse_second_reply","content":"pub fn parse_second_reply(reply: List(#(String, Value)), server_signature: BitString) -&gt; Result(\n  Nil,\n  Nil,\n)\n\nSynonyms:\nmongo/scram.parse_second_reply\nmongo/scram parse_second_reply","url":"mongo/scram.html#parse_second_reply"},{"doc":"mongo/scram","title":"second_message","content":"pub fn second_message(server_params: #(String, String, Int), first_payload: String, server_payload: String, cid: Int, password: String) -&gt; Result(\n  #(Value, BitString),\n  Nil,\n)\n\nSynonyms:\nmongo/scram.second_message\nmongo/scram second_message","url":"mongo/scram.html#second_message"},{"doc":"mongo/scram","title":"mongo/scram","content":"","url":"mongo/scram.html"},{"doc":"mongo/client","title":"Collection","content":"pub type Collection {\n  Collection(db: Database, name: String)\n}\n\nCollection(db: Database, name: String)\n\n\nSynonyms:\nmongo/client.Collection\nmongo/client Collection","url":"mongo/client.html#Collection"},{"doc":"mongo/client","title":"ConnectionInfo","content":"pub opaque type ConnectionInfo\n\n\nSynonyms:\nmongo/client.ConnectionInfo\nmongo/client ConnectionInfo","url":"mongo/client.html#ConnectionInfo"},{"doc":"mongo/client","title":"Database","content":"pub type Database {\n  Database(socket: tcp.Socket, name: String)\n}\n\nDatabase(socket: tcp.Socket, name: String)\n\n\nSynonyms:\nmongo/client.Database\nmongo/client Database","url":"mongo/client.html#Database"},{"doc":"mongo/client","title":"collection","content":"pub fn collection(db: Database, name: String) -&gt; Collection\n\nSynonyms:\nmongo/client.collection\nmongo/client collection","url":"mongo/client.html#collection"},{"doc":"mongo/client","title":"connect","content":"pub fn connect(uri: String) -&gt; Result(Database, Nil)\n\nSynonyms:\nmongo/client.connect\nmongo/client connect","url":"mongo/client.html#connect"},{"doc":"mongo/client","title":"execute","content":"pub fn execute(collection: Collection, cmd: Value) -&gt; Result(\n  List(#(String, Value)),\n  #(Int, String),\n)\n\nSynonyms:\nmongo/client.execute\nmongo/client execute","url":"mongo/client.html#execute"},{"doc":"mongo/client","title":"mongo/client","content":"","url":"mongo/client.html"},{"doc":"mongo/crud","title":"InsertResult","content":"pub type InsertResult {\n  InsertResult(inserted: Int, inserted_ids: List(types.Value))\n}\n\nInsertResult(inserted: Int, inserted_ids: List(types.Value))\n\n\nSynonyms:\nmongo/crud.InsertResult\nmongo/crud InsertResult","url":"mongo/crud.html#InsertResult"},{"doc":"mongo/crud","title":"UpdateResult","content":"pub type UpdateResult {\n  UpdateResult(matched: Int, modified: Int)\n  UpsertResult(matched: Int, upserted_id: types.Value)\n}\n\nUpdateResult(matched: Int, modified: Int)\n\n\nUpsertResult(matched: Int, upserted_id: types.Value)\n\n\nSynonyms:\nmongo/crud.UpdateResult\nmongo/crud UpdateResult","url":"mongo/crud.html#UpdateResult"},{"doc":"mongo/crud","title":"count","content":"pub fn count(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.count\nmongo/crud count","url":"mongo/crud.html#count"},{"doc":"mongo/crud","title":"count_all","content":"pub fn count_all(collection: Collection) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.count_all\nmongo/crud count_all","url":"mongo/crud.html#count_all"},{"doc":"mongo/crud","title":"delete_many","content":"pub fn delete_many(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.delete_many\nmongo/crud delete_many","url":"mongo/crud.html#delete_many"},{"doc":"mongo/crud","title":"delete_one","content":"pub fn delete_one(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.delete_one\nmongo/crud delete_one","url":"mongo/crud.html#delete_one"},{"doc":"mongo/crud","title":"find_all","content":"pub fn find_all(collection: Collection, options: List(FindOption)) -&gt; Result(\n  List(Value),\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.find_all\nmongo/crud find_all","url":"mongo/crud.html#find_all"},{"doc":"mongo/crud","title":"find_by_id","content":"pub fn find_by_id(collection: Collection, id: String) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.find_by_id\nmongo/crud find_by_id","url":"mongo/crud.html#find_by_id"},{"doc":"mongo/crud","title":"find_many","content":"pub fn find_many(collection: Collection, filter: Value, options: List(\n    FindOption,\n  )) -&gt; Result(List(Value), MongoError)\n\nSynonyms:\nmongo/crud.find_many\nmongo/crud find_many","url":"mongo/crud.html#find_many"},{"doc":"mongo/crud","title":"find_one","content":"pub fn find_one(collection: Collection, filter: Value, projection: Value) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.find_one\nmongo/crud find_one","url":"mongo/crud.html#find_one"},{"doc":"mongo/crud","title":"insert_many","content":"pub fn insert_many(collection: Collection, docs: List(Value)) -&gt; Result(\n  InsertResult,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.insert_many\nmongo/crud insert_many","url":"mongo/crud.html#insert_many"},{"doc":"mongo/crud","title":"insert_one","content":"pub fn insert_one(collection: Collection, doc: Value) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.insert_one\nmongo/crud insert_one","url":"mongo/crud.html#insert_one"},{"doc":"mongo/crud","title":"update_many","content":"pub fn update_many(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmongo/crud.update_many\nmongo/crud update_many","url":"mongo/crud.html#update_many"},{"doc":"mongo/crud","title":"update_one","content":"pub fn update_one(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmongo/crud.update_one\nmongo/crud update_one","url":"mongo/crud.html#update_one"},{"doc":"mongo/crud","title":"mongo/crud","content":"","url":"mongo/crud.html"},{"doc":"mongo","title":"collection","content":"pub fn collection(db: Database, name: String) -&gt; Collection\n\nSynonyms:\nmongo.collection\nmongo collection","url":"mongo.html#collection"},{"doc":"mongo","title":"connect","content":"pub fn connect(uri: String) -&gt; Result(Database, Nil)\n\nSynonyms:\nmongo.connect\nmongo connect","url":"mongo.html#connect"},{"doc":"mongo","title":"count","content":"pub fn count(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo.count\nmongo count","url":"mongo.html#count"},{"doc":"mongo","title":"count_all","content":"pub fn count_all(collection: Collection) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo.count_all\nmongo count_all","url":"mongo.html#count_all"},{"doc":"mongo","title":"delete_many","content":"pub fn delete_many(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo.delete_many\nmongo delete_many","url":"mongo.html#delete_many"},{"doc":"mongo","title":"delete_one","content":"pub fn delete_one(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo.delete_one\nmongo delete_one","url":"mongo.html#delete_one"},{"doc":"mongo","title":"find_all","content":"pub fn find_all(collection: Collection, options: List(FindOption)) -&gt; Result(\n  List(Value),\n  MongoError,\n)\n\nSynonyms:\nmongo.find_all\nmongo find_all","url":"mongo.html#find_all"},{"doc":"mongo","title":"find_by_id","content":"pub fn find_by_id(collection: Collection, id: String) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmongo.find_by_id\nmongo find_by_id","url":"mongo.html#find_by_id"},{"doc":"mongo","title":"find_many","content":"pub fn find_many(collection: Collection, filter: Value, options: List(\n    FindOption,\n  )) -&gt; Result(List(Value), MongoError)\n\nSynonyms:\nmongo.find_many\nmongo find_many","url":"mongo.html#find_many"},{"doc":"mongo","title":"find_one","content":"pub fn find_one(collection: Collection, filter: Value, projection: Value) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmongo.find_one\nmongo find_one","url":"mongo.html#find_one"},{"doc":"mongo","title":"insert_many","content":"pub fn insert_many(collection: Collection, docs: List(Value)) -&gt; Result(\n  InsertResult,\n  MongoError,\n)\n\nSynonyms:\nmongo.insert_many\nmongo insert_many","url":"mongo.html#insert_many"},{"doc":"mongo","title":"insert_one","content":"pub fn insert_one(collection: Collection, doc: Value) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmongo.insert_one\nmongo insert_one","url":"mongo.html#insert_one"},{"doc":"mongo","title":"update_many","content":"pub fn update_many(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmongo.update_many\nmongo update_many","url":"mongo.html#update_many"},{"doc":"mongo","title":"update_one","content":"pub fn update_one(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmongo.update_one\nmongo update_one","url":"mongo.html#update_one"},{"doc":"mongo","title":"mongo","content":"","url":"mongo.html"},{"doc":"mongo/aggregation","title":"Pipeline","content":"pub opaque type Pipeline\n\n\nSynonyms:\nmongo/aggregation.Pipeline\nmongo/aggregation Pipeline","url":"mongo/aggregation.html#Pipeline"},{"doc":"mongo/aggregation","title":"add_fields","content":"pub fn add_fields(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.add_fields\nmongo/aggregation add_fields","url":"mongo/aggregation.html#add_fields"},{"doc":"mongo/aggregation","title":"aggregate","content":"pub fn aggregate(collection: Collection) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.aggregate\nmongo/aggregation aggregate","url":"mongo/aggregation.html#aggregate"},{"doc":"mongo/aggregation","title":"exec","content":"pub fn exec(pipeline: Pipeline) -&gt; Result(List(Value), MongoError)\n\nSynonyms:\nmongo/aggregation.exec\nmongo/aggregation exec","url":"mongo/aggregation.html#exec"},{"doc":"mongo/aggregation","title":"group","content":"pub fn group(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.group\nmongo/aggregation group","url":"mongo/aggregation.html#group"},{"doc":"mongo/aggregation","title":"limit","content":"pub fn limit(pipeline: Pipeline, count: Int) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.limit\nmongo/aggregation limit","url":"mongo/aggregation.html#limit"},{"doc":"mongo/aggregation","title":"lookup","content":"pub fn lookup(pipeline: Pipeline, from from: String, local_field local_field: String, foreign_field foreign_field: String, alias alias: String) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.lookup\nmongo/aggregation lookup","url":"mongo/aggregation.html#lookup"},{"doc":"mongo/aggregation","title":"match","content":"pub fn match(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.match\nmongo/aggregation match","url":"mongo/aggregation.html#match"},{"doc":"mongo/aggregation","title":"project","content":"pub fn project(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.project\nmongo/aggregation project","url":"mongo/aggregation.html#project"},{"doc":"mongo/aggregation","title":"skip","content":"pub fn skip(pipeline: Pipeline, count: Int) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.skip\nmongo/aggregation skip","url":"mongo/aggregation.html#skip"},{"doc":"mongo/aggregation","title":"sort","content":"pub fn sort(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.sort\nmongo/aggregation sort","url":"mongo/aggregation.html#sort"},{"doc":"mongo/aggregation","title":"stages","content":"pub fn stages(pipeline: Pipeline, docs: List(Value)) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.stages\nmongo/aggregation stages","url":"mongo/aggregation.html#stages"},{"doc":"mongo/aggregation","title":"mongo/aggregation","content":"","url":"mongo/aggregation.html"}]);